==> vue-sb-components-2.1.24.tgz: package/components/button/button.js <==
import "./button.css";
import { defineComponent as a, resolveComponent as d, openBlock as l, createElementBlock as r, mergeProps as i, renderSlot as n, createBlock as p, withCtx as u, createElementVNode as b } from "vue";
import f from "../tooltip/tooltip.js";
import { _ as k } from "../../_plugin-vue_export-helper-dad06003.js";
const m = a({
  emits: {
    click: (e) => !0
  },
  props: {
    color: {
      default: "default",
      type: String
    },
    disabled: {
      default: !1,
      type: Boolean
    },
    noElevation: {
      required: !1,
      type: Boolean
    },
    size: {
      default: "base",
      type: String
    },
    tooltip: {
      required: !1,
      type: String
    },
    variant: {
      default: "contained",
      type: String
    }
  },
  name: "sb-button",
  components: {
    "sb-tooltip": f
  },
  data() {
    return { isClicked: !1 };
  },
  methods: {
    handleClick(e) {
      this.isClicked = !0, setTimeout(() => {
        this.isClicked = !1;
      }, 250), this.$emit("click", e);
    }
  }
});
const c = ["disabled"], C = ["disabled"];
function v(e, t, $, y, h, B) {
  const s = d("sb-tooltip");
  return e.tooltip ? (l(), p(s, {
    key: 1,
    label: e.tooltip
  }, {
    default: u(() => [
      b("button", i({
        class: ["btn", [
          `btn-${e.variant}`,
          e.size,
          e.color,
          e.isClicked && "clicked",
          e.noElevation && "no-elevation"
        ]],
        disabled: e.disabled,
        onClick: t[1] || (t[1] = (...o) => e.handleClick && e.handleClick(...o))
      }, { ...e.$attrs }), [
        n(e.$slots, "default")
      ], 16, C)
    ]),
    _: 3
  }, 8, ["label"])) : (l(), r("button", i({
    key: 0,
    class: ["btn", [
      `btn-${e.variant}`,
      e.size,
      e.color,
      e.isClicked && "clicked",
      e.noElevation && "no-elevation"
    ]],
    disabled: e.disabled,
    onClick: t[0] || (t[0] = (...o) => e.handleClick && e.handleClick(...o))
  }, { ...e.$attrs }), [
    n(e.$slots, "default")
  ], 16, c));
}
const z = /* @__PURE__ */ k(m, [["render", v]]);
export {
  z as default
};

==> vue-sb-components-2.2.11.tgz: package/components/button/button.js <==
import "./button.css";
import { defineComponent as a, resolveComponent as d, openBlock as l, createElementBlock as r, mergeProps as i, renderSlot as n, createBlock as p, withCtx as u, createElementVNode as b, normalizeClass as f } from "vue";
import k from "../tooltip/tooltip.js";
import { _ as m } from "../../_plugin-vue_export-helper-dad06003.js";
const c = a({
  emits: {
    click: (e) => !0
  },
  props: {
    color: {
      default: "default",
      type: String
    },
    disabled: {
      default: !1,
      type: Boolean
    },
    noElevation: {
      required: !1,
      type: Boolean
    },
    size: {
      default: "base",
      type: String
    },
    tooltip: {
      required: !1,
      type: String
    },
    variant: {
      default: "contained",
      type: String
    }
  },
  name: "sb-button",
  components: {
    "sb-tooltip": k
  },
  data() {
    return { isClicked: !1 };
  },
  methods: {
    handleClick(e) {
      this.isClicked = !0, setTimeout(() => {
        this.isClicked = !1;
      }, 250), this.$emit("click", e);
    }
  }
});
const C = ["disabled"], v = ["disabled"];
function $(e, t, y, h, B, g) {
  const s = d("sb-tooltip");
  return e.tooltip ? (l(), p(s, i({
    key: 1,
    label: e.tooltip
  }, { ...e.$attrs }), {
    default: u(() => [
      b("button", {
        class: f(["btn", [
          `btn-${e.variant}`,
          e.size,
          e.color,
          e.isClicked && "clicked",
          e.noElevation && "no-elevation"
        ]]),
        disabled: e.disabled,
        onClick: t[1] || (t[1] = (...o) => e.handleClick && e.handleClick(...o))
      }, [
        n(e.$slots, "default")
      ], 10, v)
    ]),
    _: 3
  }, 16, ["label"])) : (l(), r("button", i({
    key: 0,
    class: ["btn", [
      `btn-${e.variant}`,
      e.size,
      e.color,
      e.isClicked && "clicked",
      e.noElevation && "no-elevation"
    ]],
    disabled: e.disabled,
    onClick: t[0] || (t[0] = (...o) => e.handleClick && e.handleClick(...o))
  }, { ...e.$attrs }), [
    n(e.$slots, "default")
  ], 16, C));
}
const q = /* @__PURE__ */ m(c, [["render", $]]);
export {
  q as default
};
